@@ -14,14 +14,15 @@ import time
 import uuid
 import asyncio
 from logging import Logger
-from playwright.async_api import async_playwright
+from contextlib import asynccontextmanager
 from playwright_helper.utils.type_utils import RunResult
+from playwright._impl._api_structures import ViewportSize
 from playwright_helper.utils.log_utils import logger as log
 from playwright_helper.libs.browser_pool import BrowserPool
 from playwright_helper.utils.file_handle import get_caller_dir
 from typing import Any, List, Optional, cast, Callable, Literal, Dict
 from playwright.async_api import Page, Browser, BrowserContext, TimeoutError as PlaywrightTimeoutError, \
-    Error as PlaywrightError
+    Error as PlaywrightError, async_playwright
 
 
 class PlaywrightBrowserExecutor:
@@ -38,6 +39,8 @@ class PlaywrightBrowserExecutor:
             video_dir: str = None,
             trace_dir: str = None,
             screenshot_dir: str = None,
+            viewport: Optional[ViewportSize] = None,
+            user_agent: Optional[str] = None,
             storage_state: Optional[Dict[str, Any]] = None,
             **browser_config: Any,
     ):
@@ -46,6 +49,8 @@ class PlaywrightBrowserExecutor:
         self.browser_pool = browser_pool
         self.middlewares = middlewares or []
         self.retries = retries
+        self.user_agent = user_agent
+        self.viewport = viewport
 
         self.record_video = record_video
         self.record_trace = record_trace
@@ -67,7 +72,7 @@ class PlaywrightBrowserExecutor:
                 name = f"error_{int(time.time())}"
             path = os.path.join(self.screenshot_dir, f"{name}.png")
             await page.screenshot(path=path)
-            self.logger.info(f"[Screenshot Saved] {path}")
+            self.logger.debug(f"[Screenshot Saved] {path}")
         except Exception as e:
             self.logger.error(f"[Screenshot Failed] {e}")
 
@@ -86,11 +91,22 @@ class PlaywrightBrowserExecutor:
             await self._playwright.stop()
             self._playwright = None
 
-    async def _create_context(self) -> BrowserContext:
+    @asynccontextmanager
+    async def session(self, storage_state: Optional[Dict[str, Any]] = None):
+        context: BrowserContext = cast(BrowserContext, None)
+        try:
+            context = await self._create_context(storage_state=storage_state or self.storage_state)
+            page: Page = await context.new_page()
+            yield page
+        finally:
+            if context:
+                await self._cleanup_context(context)
+
+    async def _create_context(self, storage_state: Optional[Dict[str, Any]] = None) -> BrowserContext:
         task_id = str(uuid.uuid4())
 
         if self.mode == "persistent":
-            self.logger.info("[Executor] mode=persistent")
+            self.logger.debug("[Executor] mode=persistent")
             # persistent 模式：不走 pool
             context = await self._playwright.chromium.launch_persistent_context(
                 record_video_dir=self.video_dir if self.record_video else None,
@@ -98,12 +114,14 @@ class PlaywrightBrowserExecutor:
             )
         else:
             # 并发模式：BrowserPool
-            self.logger.info("[Executor] mode=storage")
+            self.logger.debug("[Executor] mode=storage")
 
             browser: Browser = await self.browser_pool.acquire()
 
             context = await browser.new_context(
-                storage_state=self.storage_state,
+                storage_state=storage_state or self.storage_state,
+                viewport=self.viewport,
+                user_agent=self.user_agent,
                 record_video_dir=self.video_dir if self.record_video else None,
             )
 
@@ -131,7 +149,7 @@ class PlaywrightBrowserExecutor:
         try:
             await context.close()
         except Exception as e:
-            self.logger.debug(f"[Cleanup] ignore close error: {e}")
+            self.logger.warning(f"[Cleanup] ignore close error: {e}")
 
         browser = getattr(context, "_browser", None)
         if browser:
@@ -149,7 +167,9 @@ class PlaywrightBrowserExecutor:
         # Main callback
         return await callback(page=page, logger=self.logger, context=context, **kwargs)
 
-    async def run(self, *, callback: Callable, **kwargs: Any) -> RunResult:
+    async def run(
+            self, *, callback: Callable, storage_state: Optional[Dict[str, Any]] = None, **kwargs: Any
+    ) -> RunResult:
         attempt = 0
         last_error: Optional[Exception] = None
         task_id: Optional[str] = "unknown"
@@ -159,7 +179,7 @@ class PlaywrightBrowserExecutor:
             page = None
             context: BrowserContext = cast(BrowserContext, None)
             try:
-                context = await self._create_context()
+                context = await self._create_context(storage_state=storage_state)
                 task_id = getattr(context, "_task_id", "unknown")
                 page = await context.new_page()
 
@@ -183,7 +203,7 @@ class PlaywrightBrowserExecutor:
                     os.makedirs(self.trace_dir, exist_ok=True)
                     trace_path = os.path.join(self.trace_dir, f"{task_id}.zip")
                     await context.tracing.stop(path=trace_path)
-                    self.logger.error(f"[Trace Saved] {trace_path}")
+                    self.logger.debug(f"[Trace Saved] {trace_path}")
 
                 # ❗关键：不要 raise
                 return RunResult(
@@ -193,7 +213,7 @@ class PlaywrightBrowserExecutor:
                     task_id=task_id,
                     result=result
                 )
-            except (PlaywrightTimeoutError, PlaywrightError, Exception) as e:
+            except (PlaywrightTimeoutError, PlaywrightError, RuntimeError, EnvironmentError, Exception) as e:
                 last_error = e
                 self.logger.error(f"[Task<{task_id}> Attempt {attempt + 1} Failed] {e}")
                 if page:
@@ -203,7 +223,7 @@ class PlaywrightBrowserExecutor:
                     os.makedirs(self.trace_dir, exist_ok=True)
                     trace_path = os.path.join(self.trace_dir, f"{task_id}.zip")
                     await context.tracing.stop(path=trace_path)
-                    self.logger.error(f"[Trace Saved] {trace_path}")
+                    self.logger.debug(f"[Trace Saved] {trace_path}")
 
                 attempt += 1
                 if attempt <= self.retries:
